# Changelog


## 0.1.1 (2015-12-14)

* More manipulations with smiles; selection support; copying of categories
* Real-time preview of smile size
* More user friendly addition of custom smiles
* Added lossless compression of smiles


## 0.1.0 (2015-11-28)

* First release on PyPI.
